<?php
/**
 * Helper functions for the Customizer.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_is_posts_page' ) ) {
	/**
	 * Check to see if we're on a posts page
	 *
	 * @since 1.0.0
	 */
	function xena_is_posts_page() {
		return ( is_home() || is_archive() || is_tax() ) ? true : false;
	}
}

if ( ! function_exists( 'xena_is_footer_bar_active' ) ) {
	/**
	 * Check to see if we're using our footer bar widget
	 *
	 * @since 1.0.0
	 */
	function xena_is_footer_bar_active() {
		return ( is_active_sidebar( 'footer-bar' ) ) ? true : false;
	}
}

if ( ! function_exists( 'xena_is_top_bar_active' ) ) {
	/**
	 * Check to see if the top bar is active
	 *
	 * @since 1.0.0
	 */
	function xena_is_top_bar_active() {
		$top_bar = is_active_sidebar( 'top-bar' ) ? true : false;
		return apply_filters( 'xena_is_top_bar_active', $top_bar );
	}
}

if ( ! function_exists( 'xena_hidden_navigation' ) && function_exists( 'is_customize_preview' ) ) {
	add_action( 'wp_footer', 'xena_hidden_navigation' );
	/**
	 * Adds a hidden navigation if no navigation is set
	 * This allows us to use postMessage to position the navigation when it doesn't exist
	 *
	 * @since 1.0.0
	 */
	function xena_hidden_navigation() {
		if ( is_customize_preview() && function_exists( 'xena_navigation_position' ) ) {
			?>
			<div style="display:none;">
				<?php xena_navigation_position(); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'xena_customize_partial_blogname' ) ) {
	/**
	 * Render the site title for the selective refresh partial.
	 *
	 * @since 1.0.0
	 */
	function xena_customize_partial_blogname() {
		bloginfo( 'name' );
	}
}

if ( ! function_exists( 'xena_customize_partial_blogdescription' ) ) {
	/**
	 * Render the site tagline for the selective refresh partial.
	 *
	 * @since 1.0.0
	 */
	function xena_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}
}

if ( ! function_exists( 'xena_enqueue_color_palettes' ) ) {
	add_action( 'customize_controls_enqueue_scripts', 'xena_enqueue_color_palettes' );
	/**
	 * Add our custom color palettes to the color pickers in the Customizer.
	 *
	 * @since 1.0.0
	 */
	function xena_enqueue_color_palettes() {
		// Old versions of WP don't get nice things.
		if ( ! function_exists( 'wp_add_inline_script' ) ) {
			return;
		}

		// Grab our palette array and turn it into JS.
		$palettes = wp_json_encode( xena_get_default_color_palettes() );

		// Add our custom palettes.
		// json_encode takes care of escaping.
		wp_add_inline_script( 'wp-color-picker', 'jQuery.wp.wpColorPicker.prototype.options.palettes = ' . $palettes . ';' );
	}
}

if ( ! function_exists( 'xena_sanitize_integer' ) ) {
	/**
	 * Sanitize integers.
	 *
	 * @param string $input input.
	 *
	 * @since 1.0.8
	 */
	function xena_sanitize_integer( $input ) {
		return absint( $input );
	}
}

if ( ! function_exists( 'xena_sanitize_decimal_integer' ) ) {
	/**
	 * Sanitize integers that can use decimals.
	 *
	 * @param string $input input.
	 *
	 * @since 1.0.0
	 */
	function xena_sanitize_decimal_integer( $input ) {
		return abs( floatval( $input ) );
	}
}

/**
 * Sanitize a positive number, but allow an empty value.
 *
 * @param string $input input.
 *
 * @since 1.0.0
 */
function xena_sanitize_empty_absint( $input ) {
	if ( '' === $input ) {
		return '';
	}

	return absint( $input );
}

if ( ! function_exists( 'xena_sanitize_checkbox' ) ) {
	/**
	 * Sanitize checkbox values.
	 *
	 * @param string $checked checked.
	 *
	 * @since 1.0.0
	 */
	function xena_sanitize_checkbox( $checked ) {
		return ( ( isset( $checked ) && true === $checked ) ? true : false );
	}
}

if ( ! function_exists( 'xena_sanitize_blog_excerpt' ) ) {
	/**
	 * Sanitize blog excerpt.
	 *
	 * @param string $input input.
	 *
	 * @since 1.0.0
	 */
	function xena_sanitize_blog_excerpt( $input ) {
		$valid = array(
			'full',
			'excerpt',
		);

		if ( in_array( $input, $valid, true ) ) {
			return $input;
		} else {
			return 'full';
		}
	}
}

if ( ! function_exists( 'xena_sanitize_hex_color' ) ) {
	/**
	 * Sanitize colors.
	 * Allow blank value.
	 *
	 * @param string $color color.
	 *
	 * @since 1.0.0
	 */
	function xena_sanitize_hex_color( $color ) {
		if ( '' === $color ) {
			return '';
		}

		// 3 or 6 hex digits, or the empty string.
		if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
			return $color;
		}

		return '';
	}
}

/**
 * Sanitize RGBA colors.
 *
 * @param string $color color.
 *
 * @since 1.0.0
 */
function xena_sanitize_rgba_color( $color ) {
	if ( '' === $color ) {
		return '';
	}

	if ( false === strpos( $color, 'rgba' ) ) {
		return xena_sanitize_hex_color( $color );
	}

	$color = str_replace( ' ', '', $color );
	sscanf( $color, 'rgba(%d,%d,%d,%f)', $red, $green, $blue, $alpha );

	return 'rgba(' . $red . ',' . $green . ',' . $blue . ',' . $alpha . ')';
}

if ( ! function_exists( 'xena_sanitize_choices' ) ) {
	/**
	 * Sanitize choices.
	 *
	 * @param string $input input.
	 * @param string $setting setting.
	 *
	 * @since 1.0.0
	 */
	function xena_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug.
		$input = sanitize_key( $input );

		// Get list of choices from the control.
		// associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it.
		// otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

/**
 * Sanitize our Google Font variants
 *
 * @param string $input input.
 *
 * @since 1.0.0
 */
function xena_sanitize_variants( $input ) {
	if ( is_array( $input ) ) {
		$input = implode( ',', $input );
	}
	return sanitize_text_field( $input );
}

/**
 * Sanitize our Google Fonts
 *
 * @param string               $input input.
 * @param WP_Customize_Setting $setting customizer setting.
 *
 * @since 1.0.5
 */
function xena_sanitize_fonts( $input, $setting ) {

	// Check for a valid system font first.
	$system_fonts = xena_typography_default_fonts();

	if ( in_array( $input, $system_fonts, true ) ) {
		return $input;
	}

	// Check for a valid google font.
	$google_fonts = xena_get_all_google_fonts();

	// Google fonts are stored in a keyed array.
	// Convert $input to a key and then santitize for array lookup.
	$key = sanitize_key( strtolower( str_replace( ' ', '_', $input ) ) );

	if ( array_key_exists( $key, $google_fonts ) ) {
		return $input;
	}

	// Font is not valid so return default font.
	return $setting->default;

}

add_action( 'customize_controls_enqueue_scripts', 'xena_do_control_inline_scripts', 100 );
/**
 * Add misc inline scripts to our controls.
 *
 * We don't want to add these to the controls themselves, as they will be repeated
 * each time the control is initialized.
 *
 * @since 1.0.0
 */
function xena_do_control_inline_scripts() {
	wp_localize_script(
		'xena-typography-customizer',
		'xena_customize',
		array(
			'nonce' => wp_create_nonce( 'xena_customize_nonce' ),
		)
	);

	$number_of_fonts = apply_filters( 'xena_number_of_fonts', 200 );

	wp_localize_script(
		'xena-typography-customizer',
		'xenaTypography',
		array(
			'googleFonts' => apply_filters( 'xena_typography_customize_list', xena_get_all_google_fonts( $number_of_fonts ) ),
		)
	);

	wp_localize_script( 'xena-typography-customizer', 'xena_typography_defaults', xena_typography_default_fonts() );

	wp_enqueue_script( 'xena-customizer-controls', trailingslashit( get_template_directory_uri() ) . 'inc/customizer/controls/js/customizer-controls.js', array( 'customize-controls', 'jquery' ), XENA_VERSION, true );
	wp_localize_script( 'xena-customizer-controls', 'xena_defaults', xena_get_defaults() );
	wp_localize_script( 'xena-customizer-controls', 'xena_color_defaults', xena_get_color_defaults() );
}

if ( ! function_exists( 'xena_customizer_live_preview' ) ) {
	add_action( 'customize_preview_init', 'xena_customizer_live_preview', 100 );
	/**
	 * Add our live preview scripts
	 *
	 * @since 1.0.0
	 */
	function xena_customizer_live_preview() {
		$spacing_settings = wp_parse_args(
			get_option( 'xena_spacing_settings', array() ),
			xena_spacing_get_defaults()
		);

		wp_enqueue_script( 'xena-themecustomizer', trailingslashit( get_template_directory_uri() ) . 'inc/customizer/controls/js/customizer-live-preview.js', array( 'customize-preview' ), XENA_VERSION, true );

		wp_localize_script(
			'xena-themecustomizer',
			'xena_live_preview',
			array(
				'mobile'       => xena_get_media_query( 'mobile' ),
				'tablet'       => xena_get_media_query( 'tablet' ),
				'desktop'      => xena_get_media_query( 'desktop' ),
				'contentLeft'  => absint( $spacing_settings['content_left'] ),
				'contentRight' => absint( $spacing_settings['content_right'] ),
			) 
		);
	}
}

/**
 * Check to see if we have a logo or not.
 *
 * Used as an active callback. Calling has_custom_logo creates a PHP notice for
 * multisite users.
 *
 * @since 1.0.0
 */
function xena_has_custom_logo_callback() {
	if ( get_theme_mod( 'custom_logo' ) ) {
		return true;
	}

	return false;
}

/**
 * Save our preset layout controls. These should always save to be "current".
 *
 * @param string $input input.
 *
 * @since 1.0.0
 */
function xena_sanitize_preset_layout( $input ) {
	return 'current';
}
