<?php
/**
 * General functions.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'xena_scripts' );
	/**
	 * Enqueue scripts and styles
	 */
	function xena_scripts() {
		$suffix  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';
		$dir_uri = get_template_directory_uri();

		wp_enqueue_style( 'xena-style', $dir_uri . "/style{$suffix}.css", array(), XENA_VERSION, 'all' );

		if ( is_child_theme() ) {
			wp_enqueue_style( 'xena-child', get_stylesheet_uri(), array( 'xena-style' ), filemtime( get_stylesheet_directory() . '/style.css' ), 'all' );
		}

		if ( function_exists( 'wp_script_add_data' ) ) {
			wp_enqueue_script( 'xena-classlist', $dir_uri . "/js/classList{$suffix}.js", array(), XENA_VERSION, true );
			wp_script_add_data( 'xena-classlist', 'conditional', 'lte IE 11' );
		}

		wp_enqueue_script( 'xena-menu', $dir_uri . "/js/menu{$suffix}.js", array(), XENA_VERSION, true );
		wp_enqueue_script( 'xena-a11y', $dir_uri . "/js/a11y{$suffix}.js", array(), XENA_VERSION, true );

		if ( 'click' === xena_get_option( 'nav_dropdown_type' ) || 'click-arrow' === xena_get_option( 'nav_dropdown_type' ) ) {
			wp_enqueue_script( 'xena-dropdown-click', $dir_uri . "/js/dropdown-click{$suffix}.js", array( 'xena-menu' ), XENA_VERSION, true );
		}

		if ( 'enable' === xena_get_option( 'nav_search' ) ) {
			wp_enqueue_script( 'xena-navigation-search', $dir_uri . "/js/navigation-search{$suffix}.js", array( 'xena-menu' ), XENA_VERSION, true );

			wp_localize_script(
				'xena-navigation-search',
				'xenaNavSearch',
				array(
					'open'  => esc_attr__( 'Open Search Bar', 'xena' ),
					'close' => esc_attr__( 'Close Search Bar', 'xena' ),
				)
			);
		}

		if ( 'enable' === xena_get_option( 'back_to_top' ) ) {
			wp_enqueue_script( 'xena-back-to-top', $dir_uri . "/js/back-to-top{$suffix}.js", array(), XENA_VERSION, true );
		}

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
}

if ( ! function_exists( 'xena_widgets_init' ) ) {
	add_action( 'widgets_init', 'xena_widgets_init' );
	/**
	 * Register widgetized area and update sidebar with default widgets
	 */
	function xena_widgets_init() {
		$widgets = array(
			'sidebar-1'  => esc_html__( 'Right Sidebar', 'xena' ),
			'sidebar-2'  => esc_html__( 'Left Sidebar', 'xena' ),
			'header'     => esc_html__( 'Header', 'xena' ),
			'footer-1'   => esc_html__( 'Footer Widget 1', 'xena' ),
			'footer-2'   => esc_html__( 'Footer Widget 2', 'xena' ),
			'footer-3'   => esc_html__( 'Footer Widget 3', 'xena' ),
			'footer-4'   => esc_html__( 'Footer Widget 4', 'xena' ),
			'footer-5'   => esc_html__( 'Footer Widget 5', 'xena' ),
			'footer-bar' => esc_html__( 'Footer Bar', 'xena' ),
			'top-bar'    => esc_html__( 'Top Bar', 'xena' ),
		);

		foreach ( $widgets as $id => $name ) {
			register_sidebar(
				array(
					'name'          => $name,
					'id'            => $id,
					'before_widget' => '<aside id="%1$s" class="widget inner-padding %2$s">',
					'after_widget'  => apply_filters( 'xena_after_widget', '</aside>', $name, $id ),
					'before_title'  => apply_filters( 'xena_start_widget_title', '<h2 class="widget-title">' ),
					'after_title'   => apply_filters( 'xena_end_widget_title', '</h2>' ),
				) 
			);
		}
	}
}

if ( ! function_exists( 'xena_smart_content_width' ) ) {
	add_action( 'wp', 'xena_smart_content_width' );
	/**
	 * Set the $content_width depending on layout of current page
	 * Hook into "wp" so we have the correct layout setting from xena_get_layout()
	 * Hooking into "after_setup_theme" doesn't get the correct layout setting
	 */
	function xena_smart_content_width() {
		global $content_width;

		$container_width     = xena_get_option( 'container_width' );
		$right_sidebar_width = apply_filters( 'xena_right_sidebar_width', '25' );
		$left_sidebar_width  = apply_filters( 'xena_left_sidebar_width', '25' );
		$layout              = xena_get_layout();

		if ( 'left-sidebar' === $layout ) {
			$content_width = $container_width * ( ( 100 - $left_sidebar_width ) / 100 );
		} elseif ( 'right-sidebar' === $layout ) {
			$content_width = $container_width * ( ( 100 - $right_sidebar_width ) / 100 );
		} elseif ( 'no-sidebar' === $layout ) {
			$content_width = $container_width;
		} else {
			$content_width = $container_width * ( ( 100 - ( $left_sidebar_width + $right_sidebar_width ) ) / 100 );
		}
	}
}

if ( ! function_exists( 'xena_page_menu_args' ) ) {
	add_filter( 'wp_page_menu_args', 'xena_page_menu_args' );
	/**
	 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
	 *
	 * @param array $args The existing menu args.
	 *
	 * @return array Menu args.
	 * @since 1.0.0
	 */
	function xena_page_menu_args( $args ) {
		$args['show_home'] = true;

		return $args;
	}
}

if ( ! function_exists( 'xena_disable_title' ) ) {
	add_filter( 'xena_show_title', 'xena_disable_title' );
	/**
	 * Remove our title if set.
	 *
	 * @param bool $title Whether the title is displayed or not.
	 *
	 * @return bool Whether to display the content title.
	 * @since 1.0.0
	 */
	function xena_disable_title( $title ) {
		if ( is_singular() ) {
			$disable_title = get_post_meta( get_the_ID(), '_xena-disable-headline', true );

			if ( $disable_title ) {
				$title = false;
			}
		}

		return $title;
	}
}

if ( ! function_exists( 'xena_resource_hints' ) ) {
	add_filter( 'wp_resource_hints', 'xena_resource_hints', 10, 2 );
	/**
	 * Add resource hints to our Google fonts call.
	 *
	 * @param array  $urls URLs to print for resource hints.
	 * @param string $relation_type The relation type the URLs are printed.
	 *
	 * @return array $urls           URLs to print for resource hints.
	 * @since 1.0.0
	 */
	function xena_resource_hints( $urls, $relation_type ) {
		if ( wp_style_is( 'xena-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
			if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '>=' ) ) {
				$urls[] = array(
					'href' => 'https://fonts.gstatic.com',
					'crossorigin',
				);
			} else {
				$urls[] = 'https://fonts.gstatic.com';
			}
		}

		return $urls;
	}
}

if ( ! function_exists( 'xena_remove_caption_padding' ) ) {
	add_filter( 'img_caption_shortcode_width', 'xena_remove_caption_padding' );
	/**
	 * Remove WordPress's default padding on images with captions
	 *
	 * @param int $width Default WP .wp-caption width (image width + 10px).
	 *
	 * @return int Updated width to remove 10px padding
	 */
	function xena_remove_caption_padding( $width ) {
		return $width - 10;
	}
}

if ( ! function_exists( 'xena_enhanced_image_navigation' ) ) {
	add_filter( 'attachment_link', 'xena_enhanced_image_navigation', 10, 2 );
	/**
	 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
	 *
	 * @param string $url Url.
	 * @param string $id Id.
	 */
	function xena_enhanced_image_navigation( $url, $id ) {
		if ( ! is_attachment() && ! wp_attachment_is_image( $id ) ) {
			return $url;
		}

		$image = get_post( $id );
		if ( ! empty( $image->post_parent ) && $image->post_parent !== $id ) {
			$url .= '#main';
		}

		return $url;
	}
}

if ( ! function_exists( 'xena_categorized_blog' ) ) {
	/**
	 * Determine whether blog/site has more than one category.
	 *
	 * @return bool True of there is more than one category, false otherwise.
	 * @since 1.0.0
	 */
	function xena_categorized_blog() {
		$all_the_cool_cats = get_transient( 'xena_categories' );
		if ( false === ( $all_the_cool_cats ) ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories(
				array(
					'fields'     => 'ids',
					'hide_empty' => 1,

					// We only need to know if there is more than one category.
					'number'     => 2,
				) 
			);

			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'xena_categories', $all_the_cool_cats );
		}

		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so twentyfifteen_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so twentyfifteen_categorized_blog should return false.
			return false;
		}
	}
}

if ( ! function_exists( 'xena_category_transient_flusher' ) ) {
	add_action( 'edit_category', 'xena_category_transient_flusher' );
	add_action( 'save_post', 'xena_category_transient_flusher' );
	/**
	 * Flush out the transients used in {@see xena_categorized_blog()}.
	 *
	 * @since 1.0.0
	 */
	function xena_category_transient_flusher() {
		// Like, beat it. Dig?
		delete_transient( 'xena_categories' );
	}
}

if ( ! function_exists( 'xena_get_default_color_palettes' ) ) {
	/**
	 * Set up our colors for the color picker palettes and filter them so you can change them.
	 *
	 * @since 1.0.0
	 */
	function xena_get_default_color_palettes() {
		$palettes = array(
			'#000000',
			'#FFFFFF',
			'#F1C40F',
			'#E74C3C',
			'#1ABC9C',
			'#1e72bd',
			'#8E44AD',
			'#00CC77',
		);

		return apply_filters( 'xena_default_color_palettes', $palettes );
	}
}

add_filter( 'xena_dynamic_css_skip_cache', 'xena_skip_dynamic_css_cache' );
/**
 * Skips caching of the dynamic CSS if set to false.
 *
 * @param bool $cache Cache.
 *
 * @return bool
 * @since 1.0.0
 */
function xena_skip_dynamic_css_cache( $cache ) {
	if ( ! xena_get_option( 'dynamic_css_cache' ) ) {
		return true;
	}

	return $cache;
}

add_filter( 'wp_headers', 'xena_set_wp_headers' );
/**
 * Set any necessary headers.
 *
 * @param string $headers Headers.
 * @since 1.0.0
 */
function xena_set_wp_headers( $headers ) {
	$headers['X-UA-Compatible'] = 'IE=edge';

	return $headers;
}
