<?php
/**
 * Adds HTML markup.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Display HTML classes for an element.
 *
 * @since 1.0.0
 *
 * @param string       $context The element we're targeting.
 * @param string|array $class One or more classes to add to the class list.
 */
function xena_do_element_classes( $context, $class = '' ) {
	echo 'class="' . join( ' ', xena_get_element_classes( $context, $class ) ) . '"'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
}

/**
 * Retrieve HTML classes for an element.
 *
 * @since 1.0.0
 *
 * @param string       $context The element we're targeting.
 * @param string|array $class One or more classes to add to the class list.
 * @return array Array of classes.
 */
function xena_get_element_classes( $context, $class = '' ) {
	$classes = array();

	if ( ! empty( $class ) ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}

		$classes = array_merge( $classes, $class );
	}

	$classes = array_map( 'esc_attr', $classes );

	return apply_filters( "xena_{$context}_class", $classes, $class );
}

/**
 * Get any necessary microdata.
 *
 * @since 1.0.0
 *
 * @param string $context The element to target.
 * @return string Our final attribute to add to the element.
 */
function xena_get_microdata( $context ) {
	$data = false;

	if ( 'microdata' !== apply_filters( 'xena_schema_type', 'microdata' ) ) {
		return false;
	}

	if ( 'body' === $context ) {
		$type = 'WebPage';

		if ( is_home() || is_archive() || is_attachment() || is_tax() || is_single() ) {
			$type = 'Blog';
		}

		if ( is_search() ) {
			$type = 'SearchResultsPage';
		}

		$type = apply_filters( 'xena_body_itemtype', $type );

		$data = sprintf(
			'itemtype="https://schema.org/%s" itemscope',
			esc_attr( $type )
		);
	}

	if ( 'header' === $context ) {
		$data = 'itemtype="https://schema.org/WPHeader" itemscope';
	}

	if ( 'navigation' === $context ) {
		$data = 'itemtype="https://schema.org/SiteNavigationElement" itemscope';
	}

	if ( 'article' === $context ) {
		$type = apply_filters( 'xena_article_itemtype', 'CreativeWork' );

		$data = sprintf(
			'itemtype="https://schema.org/%s" itemscope',
			esc_attr( $type )
		);
	}

	if ( 'post-author' === $context ) {
		$data = 'itemprop="author" itemtype="https://schema.org/Person" itemscope';
	}

	if ( 'comment-body' === $context ) {
		$data = 'itemtype="https://schema.org/Comment" itemscope';
	}

	if ( 'comment-author' === $context ) {
		$data = 'itemprop="author" itemtype="https://schema.org/Person" itemscope';
	}

	if ( 'sidebar' === $context ) {
		$data = 'itemtype="https://schema.org/WPSideBar" itemscope';
	}

	if ( 'footer' === $context ) {
		$data = 'itemtype="https://schema.org/WPFooter" itemscope';
	}

	if ( $data ) {
		return apply_filters( "xena_{$context}_microdata", $data );
	}
}

/**
 * Output our microdata for an element.
 *
 * @since 1.0.0
 *
 * @param string $context The element to target.
 */
function xena_do_microdata( $context ) {
	echo xena_get_microdata( $context ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
}

if ( ! function_exists( 'xena_body_classes' ) ) {
	add_filter( 'body_class', 'xena_body_classes' );
	/**
	 * Adds custom classes to the array of body classes.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_body_classes( $classes ) {
		$sidebar_layout       = xena_get_layout();
		$navigation_location  = xena_get_navigation_location();
		$navigation_alignment = xena_get_option( 'nav_alignment_setting' );
		$navigation_dropdown  = xena_get_option( 'nav_dropdown_type' );
		$header_layout        = xena_get_option( 'header_layout_setting' );
		$header_alignment     = xena_get_option( 'header_alignment_setting' );
		$content_layout       = xena_get_option( 'content_layout_setting' );
		$footer_widgets       = xena_get_footer_widgets();

		// These values all have defaults, but we like to be extra careful.
		$classes[] = ( $sidebar_layout ) ? $sidebar_layout : 'right-sidebar';
		$classes[] = ( $navigation_location ) ? $navigation_location : 'nav-below-header';
		$classes[] = ( $header_layout ) ? $header_layout : 'fluid-header';
		$classes[] = ( $content_layout ) ? $content_layout : 'separate-containers';
		$classes[] = ( '' !== $footer_widgets ) ? 'active-footer-widgets-' . absint( $footer_widgets ) : 'active-footer-widgets-3';

		if ( 'enable' === xena_get_option( 'nav_search' ) ) {
			$classes[] = 'nav-search-enabled';
		}

		// Only necessary for nav before or after header.
		if ( 'nav-below-header' === $navigation_location || 'nav-above-header' === $navigation_location ) {
			if ( 'center' === $navigation_alignment ) {
				$classes[] = 'nav-aligned-center';
			} elseif ( 'right' === $navigation_alignment ) {
				$classes[] = 'nav-aligned-right';
			} elseif ( 'left' === $navigation_alignment ) {
				$classes[] = 'nav-aligned-left';
			}
		}

		if ( 'center' === $header_alignment ) {
			$classes[] = 'header-aligned-center';
		} elseif ( 'right' === $header_alignment ) {
			$classes[] = 'header-aligned-right';
		} elseif ( 'left' === $header_alignment ) {
			$classes[] = 'header-aligned-left';
		}

		if ( 'click' === $navigation_dropdown ) {
			$classes[] = 'dropdown-click';
			$classes[] = 'dropdown-click-menu-item';
		} elseif ( 'click-arrow' === $navigation_dropdown ) {
			$classes[] = 'dropdown-click-arrow';
			$classes[] = 'dropdown-click';
		} else {
			$classes[] = 'dropdown-hover';
		}

		if ( is_singular() ) {
			// Page builder container metabox option.
			// Used to be a single checkbox, hence the name/true value. Now it's a radio choice between full width and contained.
			$content_container = get_post_meta( get_the_ID(), '_xena-full-width-content', true );

			if ( $content_container ) {
				if ( 'true' === $content_container ) {
					$classes[] = 'full-width-content';
				}

				if ( 'contained' === $content_container ) {
					$classes[] = 'contained-content';
				}
			}

			if ( has_post_thumbnail() ) {
				$classes[] = 'featured-image-active';
			}
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_top_bar_classes' ) ) {
	add_filter( 'xena_top_bar_class', 'xena_top_bar_classes' );
	/**
	 * Adds custom classes to the header.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_top_bar_classes( $classes ) {
		$classes[] = 'top-bar';

		if ( 'contained' === xena_get_option( 'top_bar_width' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		$classes[] = 'top-bar-align-' . esc_attr( xena_get_option( 'top_bar_alignment' ) );

		return $classes;
	}
}

if ( ! function_exists( 'xena_right_sidebar_classes' ) ) {
	add_filter( 'xena_right_sidebar_class', 'xena_right_sidebar_classes' );
	/**
	 * Adds custom classes to the right sidebar.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_right_sidebar_classes( $classes ) {
		$right_sidebar_width = apply_filters( 'xena_right_sidebar_width', '25' );
		$left_sidebar_width  = apply_filters( 'xena_left_sidebar_width', '25' );

		$right_sidebar_tablet_width = apply_filters( 'xena_right_sidebar_tablet_width', $right_sidebar_width );
		$left_sidebar_tablet_width  = apply_filters( 'xena_left_sidebar_tablet_width', $left_sidebar_width );

		$classes[] = 'widget-area';
		$classes[] = 'grid-' . $right_sidebar_width;
		$classes[] = 'tablet-grid-' . $right_sidebar_tablet_width;
		$classes[] = 'grid-parent';
		$classes[] = 'sidebar';

		// Get the layout.
		$layout = xena_get_layout();

		if ( '' !== $layout ) {
			switch ( $layout ) {
				case 'both-left':
					$total_sidebar_width = $left_sidebar_width + $right_sidebar_width;
					$classes[]           = 'pull-' . ( 100 - $total_sidebar_width );

					$total_sidebar_tablet_width = $left_sidebar_tablet_width + $right_sidebar_tablet_width;
					$classes[]                  = 'tablet-pull-' . ( 100 - $total_sidebar_tablet_width );
					break;
			}
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_left_sidebar_classes' ) ) {
	add_filter( 'xena_left_sidebar_class', 'xena_left_sidebar_classes' );
	/**
	 * Adds custom classes to the left sidebar.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_left_sidebar_classes( $classes ) {
		$right_sidebar_width = apply_filters( 'xena_right_sidebar_width', '25' );
		$left_sidebar_width  = apply_filters( 'xena_left_sidebar_width', '25' );
		$total_sidebar_width = $left_sidebar_width + $right_sidebar_width;

		$right_sidebar_tablet_width = apply_filters( 'xena_right_sidebar_tablet_width', $right_sidebar_width );
		$left_sidebar_tablet_width  = apply_filters( 'xena_left_sidebar_tablet_width', $left_sidebar_width );
		$total_sidebar_tablet_width = $left_sidebar_tablet_width + $right_sidebar_tablet_width;

		$classes[] = 'widget-area';
		$classes[] = 'grid-' . $left_sidebar_width;
		$classes[] = 'tablet-grid-' . $left_sidebar_tablet_width;
		$classes[] = 'mobile-grid-100';
		$classes[] = 'grid-parent';
		$classes[] = 'sidebar';

		// Get the layout.
		$layout = xena_get_layout();

		if ( '' !== $layout ) {
			switch ( $layout ) {
				case 'left-sidebar':
					$classes[] = 'pull-' . ( 100 - $left_sidebar_width );
					$classes[] = 'tablet-pull-' . ( 100 - $left_sidebar_tablet_width );
					break;

				case 'both-sidebars':
				case 'both-left':
					$classes[] = 'pull-' . ( 100 - $total_sidebar_width );
					$classes[] = 'tablet-pull-' . ( 100 - $total_sidebar_tablet_width );
					break;
			}
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_content_classes' ) ) {
	add_filter( 'xena_content_class', 'xena_content_classes' );
	/**
	 * Adds custom classes to the content container.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_content_classes( $classes ) {
		$right_sidebar_width = apply_filters( 'xena_right_sidebar_width', '25' );
		$left_sidebar_width  = apply_filters( 'xena_left_sidebar_width', '25' );
		$total_sidebar_width = $left_sidebar_width + $right_sidebar_width;

		$right_sidebar_tablet_width = apply_filters( 'xena_right_sidebar_tablet_width', $right_sidebar_width );
		$left_sidebar_tablet_width  = apply_filters( 'xena_left_sidebar_tablet_width', $left_sidebar_width );
		$total_sidebar_tablet_width = $left_sidebar_tablet_width + $right_sidebar_tablet_width;

		$classes[] = 'content-area';
		$classes[] = 'grid-parent';
		$classes[] = 'mobile-grid-100';

		// Get the layout.
		$layout = xena_get_layout();

		if ( '' !== $layout ) {
			switch ( $layout ) {

				case 'right-sidebar':
					$classes[] = 'grid-' . ( 100 - $right_sidebar_width );
					$classes[] = 'tablet-grid-' . ( 100 - $right_sidebar_tablet_width );
					break;

				case 'left-sidebar':
					$classes[] = 'push-' . $left_sidebar_width;
					$classes[] = 'grid-' . ( 100 - $left_sidebar_width );
					$classes[] = 'tablet-push-' . $left_sidebar_tablet_width;
					$classes[] = 'tablet-grid-' . ( 100 - $left_sidebar_tablet_width );
					break;

				case 'no-sidebar':
					$classes[] = 'grid-100';
					$classes[] = 'tablet-grid-100';
					break;

				case 'both-sidebars':
					$classes[] = 'push-' . $left_sidebar_width;
					$classes[] = 'grid-' . ( 100 - $total_sidebar_width );
					$classes[] = 'tablet-push-' . $left_sidebar_tablet_width;
					$classes[] = 'tablet-grid-' . ( 100 - $total_sidebar_tablet_width );
					break;

				case 'both-right':
					$classes[] = 'grid-' . ( 100 - $total_sidebar_width );
					$classes[] = 'tablet-grid-' . ( 100 - $total_sidebar_tablet_width );
					break;

				case 'both-left':
					$classes[] = 'push-' . $total_sidebar_width;
					$classes[] = 'grid-' . ( 100 - $total_sidebar_width );
					$classes[] = 'tablet-push-' . $total_sidebar_tablet_width;
					$classes[] = 'tablet-grid-' . ( 100 - $total_sidebar_tablet_width );
					break;
			}
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_header_classes' ) ) {
	add_filter( 'xena_header_class', 'xena_header_classes' );
	/**
	 * Adds custom classes to the header.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_header_classes( $classes ) {
		$classes[] = 'site-header';

		if ( 'contained-header' === xena_get_option( 'header_layout_setting' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_inside_header_classes' ) ) {
	add_filter( 'xena_inside_header_class', 'xena_inside_header_classes' );
	/**
	 * Adds custom classes to inside the header.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_inside_header_classes( $classes ) {
		$classes[] = 'inside-header';

		if ( 'full-width' !== xena_get_option( 'header_inner_width' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_navigation_classes' ) ) {
	add_filter( 'xena_navigation_class', 'xena_navigation_classes' );
	/**
	 * Adds custom classes to the navigation.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_navigation_classes( $classes ) {
		$classes[] = 'main-navigation';

		if ( 'contained-nav' === xena_get_option( 'nav_layout_setting' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		if ( 'left' === xena_get_option( 'nav_dropdown_direction' ) ) {
			$nav_layout = xena_get_option( 'nav_position_setting' );

			switch ( $nav_layout ) {
				case 'nav-below-header':
				case 'nav-above-header':
				case 'nav-float-right':
				case 'nav-float-left':
					$classes[] = 'sub-menu-left';
					break;
			}
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_inside_navigation_classes' ) ) {
	add_filter( 'xena_inside_navigation_class', 'xena_inside_navigation_classes' );
	/**
	 * Adds custom classes to the inner navigation.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_inside_navigation_classes( $classes ) {
		$classes[] = 'inside-navigation';

		if ( 'full-width' !== xena_get_option( 'nav_inner_width' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_menu_classes' ) ) {
	add_filter( 'xena_menu_class', 'xena_menu_classes' );
	/**
	 * Adds custom classes to the menu.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_menu_classes( $classes ) {
		$classes[] = 'menu';
		$classes[] = 'sf-menu';

		return $classes;
	}
}

if ( ! function_exists( 'xena_footer_classes' ) ) {
	add_filter( 'xena_footer_class', 'xena_footer_classes' );
	/**
	 * Adds custom classes to the footer.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_footer_classes( $classes ) {
		$classes[] = 'site-footer';

		if ( 'contained-footer' === xena_get_option( 'footer_layout_setting' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		if ( is_active_sidebar( 'footer-bar' ) ) {
			$classes[] = 'footer-bar-active';
			$classes[] = 'footer-bar-align-' . esc_attr( xena_get_option( 'footer_bar_alignment' ) );
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_inside_footer_classes' ) ) {
	add_filter( 'xena_inside_footer_class', 'xena_inside_footer_classes' );
	/**
	 * Adds custom classes to the footer.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_inside_footer_classes( $classes ) {
		$classes[] = 'footer-widgets-container';

		if ( 'full-width' !== xena_get_option( 'footer_inner_width' ) ) {
			$classes[] = 'grid-container';
			$classes[] = 'grid-parent';
		}

		return $classes;
	}
}

if ( ! function_exists( 'xena_main_classes' ) ) {
	add_filter( 'xena_main_class', 'xena_main_classes' );
	/**
	 * Adds custom classes to the <main> element
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_main_classes( $classes ) {
		$classes[] = 'site-main';

		return $classes;
	}
}

if ( ! function_exists( 'xena_post_classes' ) ) {
	add_filter( 'post_class', 'xena_post_classes' );
	/**
	 * Adds custom classes to the <article> element.
	 * Remove .hentry class from pages to comply with structural data guidelines.
	 *
	 * @param string $classes Classes.
	 *
	 * @since 1.0.0
	 */
	function xena_post_classes( $classes ) {
		if ( 'page' === get_post_type() ) {
			$classes = array_diff( $classes, array( 'hentry' ) );
		}

		return $classes;
	}
}
