<?php
/**
 * Comment structure.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_comment' ) ) {
	/**
	 * Template for comments and pingbacks.
	 *
	 * @param string $comment comment.
	 * @param array  $args args.
	 * @param string $depth depth.
	 *
	 * Used as a callback by wp_list_comments() for displaying the comments.
	 */
	function xena_comment( $comment, $args, $depth ) {
		$args['avatar_size'] = apply_filters( 'xena_comment_avatar_size', 50 );

		if ( 'pingback' === $comment->comment_type || 'trackback' === $comment->comment_type ) : ?>

		<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<div class="comment-body">
				<?php esc_html_e( 'Pingback:', 'xena' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'xena' ), '<span class="edit-link">', '</span>' ); ?>
			</div>

		<?php else : ?>

		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
			<article id="div-comment-<?php comment_ID(); ?>" class="comment-body" <?php xena_do_microdata( 'comment-body' ); ?>>
				<footer class="comment-meta">
					<?php
					if ( 0 !== $args['avatar_size'] ) {
						echo get_avatar( $comment, $args['avatar_size'] );
					}
					?>
					<div class="comment-author-info">
						<div class="comment-author vcard" <?php xena_do_microdata( 'comment-author' ); ?>>
							<?php printf( '<cite itemprop="name" class="fn">%s</cite>', get_comment_author_link() ); ?>
						</div><!-- .comment-author -->

						<div class="entry-meta comment-metadata">
							<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
								<time datetime="<?php comment_time( 'c' ); ?>" itemprop="datePublished">
									<?php 
									printf(
										/* translators: 1: date, 2: time */
										esc_html_x( '%1$s at %2$s', '1: date, 2: time', 'xena' ),
										get_comment_date(), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
										get_comment_time() // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
									); 
									?>
								</time>
							</a>
							<?php edit_comment_link( esc_html__( 'Edit', 'xena' ), '<span class="edit-link">| ', '</span>' ); ?>
						</div><!-- .comment-metadata -->
					</div><!-- .comment-author-info -->

					<?php if ( '0' === $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'xena' ); // phpcs:ignore WordPress.Security.EscapeOutput.UnsafePrintingFunction ?></p>
					<?php endif; ?>
				</footer><!-- .comment-meta -->

				<div class="comment-content" itemprop="text">
					<?php
					/**
					 * Xena_before_comment_content hook.
					 *
					 * @since 1.0.0
					 */
					do_action( 'xena_before_comment_text', $comment, $args, $depth );

					comment_text();

					/**
					 * Xena_after_comment_content hook.
					 *
					 * @since 1.0.0
					 */
					do_action( 'xena_after_comment_text', $comment, $args, $depth );
					?>
				</div><!-- .comment-content -->
			</article><!-- .comment-body -->
			<?php
		endif;
	}
}

add_action( 'xena_after_comment_text', 'xena_do_comment_reply_link', 10, 3 );
/**
 * Add our comment reply link after the comment text.
 *
 * @param string $comment comment.
 * @param array  $args args.
 * @param string $depth depth.
 *
 * @since 1.0.0
 */
function xena_do_comment_reply_link( $comment, $args, $depth ) {
	comment_reply_link(
		array_merge(
			$args,
			array(
				'add_below' => 'div-comment',
				'depth'     => $depth,
				'max_depth' => $args['max_depth'],
				'before'    => '<span class="reply">',
				'after'     => '</span>',
			) 
		) 
	);
}

add_filter( 'comment_form_defaults', 'xena_set_comment_form_defaults' );
/**
 * Set the default settings for our comments.
 *
 * @since 1.0.0
 *
 * @param array $defaults defaults.
 * @return array
 */
function xena_set_comment_form_defaults( $defaults ) {
	$defaults['comment_field'] = sprintf(
		'<p class="comment-form-comment"><label for="comment" class="screen-reader-text">%1$s</label><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea></p>',
		esc_html__( 'Comment', 'xena' )
	);

	$defaults['comment_notes_before'] = null;
	$defaults['comment_notes_after']  = null;
	$defaults['id_form']              = 'commentform';
	$defaults['id_submit']            = 'submit';
	$defaults['title_reply']          = apply_filters( 'xena_leave_comment', esc_html__( 'Leave a Comment', 'xena' ) );
	$defaults['label_submit']         = apply_filters( 'xena_post_comment', esc_html__( 'Post Comment', 'xena' ) );

	return $defaults;
}

add_filter( 'comment_form_default_fields', 'xena_filter_comment_fields' );
/**
 * Customizes the existing comment fields.
 *
 * @since 1.0.0
 * @param array $fields fields.
 * @return array
 */
function xena_filter_comment_fields( $fields ) {
	$commenter = wp_get_current_commenter();

	$fields['author'] = sprintf(
		'<label for="author" class="screen-reader-text">%1$s</label><input placeholder="%1$s *" id="author" name="author" type="text" value="%2$s" size="30" />',
		esc_attr__( 'Name', 'xena' ),
		esc_attr( $commenter['comment_author'] )
	);

	$fields['email'] = sprintf(
		'<label for="email" class="screen-reader-text">%1$s</label><input placeholder="%1$s *" id="email" name="email" type="email" value="%2$s" size="30" />',
		esc_attr__( 'Email', 'xena' ),
		esc_attr( $commenter['comment_author_email'] )
	);

	$fields['url'] = sprintf(
		'<label for="url" class="screen-reader-text">%1$s</label><input placeholder="%1$s" id="url" name="url" type="url" value="%2$s" size="30" />',
		esc_attr__( 'Website', 'xena' ),
		esc_attr( $commenter['comment_author_url'] )
	);

	return $fields;
}
